@@ -75,6 +75,7 @@ def make_node(
 
     # Acquisition of test data for validation
     if not isinstance(graph_node_input_1, np.ndarray) \
+        and graph_node_input_1.name in tf_layers_dict \
         and 'verification_data' in tf_layers_dict[graph_node_input_1.name].keys():
         test_data1: np.ndarray = tf_layers_dict[graph_node_input_1.name]['verification_data']
     elif isinstance(graph_node_input_1, np.ndarray):
@@ -82,6 +83,7 @@ def make_node(
     else:
         test_data1 = None
     if not isinstance(graph_node_input_2, np.ndarray) \
+        and graph_node_input_2.name in tf_layers_dict \
         and 'verification_data' in tf_layers_dict[graph_node_input_2.name].keys():
         test_data2: np.ndarray = tf_layers_dict[graph_node_input_2.name]['verification_data']
     elif isinstance(graph_node_input_2, np.ndarray):
@@ -100,6 +102,7 @@ def make_node(
             graph_node_input_2=graph_node_input_2,
             input_tensor_1=input_tensor_1,
             input_tensor_2=input_tensor_2,
+            **kwargs,
         )
 
     input_tensor_1, input_tensor_2 = pre_explicit_broadcast(
@@ -124,6 +127,7 @@ def make_node(
         input_tensor_1=input_tensor_1,
         input_tensor_2=input_tensor_2,
         tf_layers_dict=tf_layers_dict,
+        **kwargs,
     )
 
     # Pre-process transpose
