@@ -18,6 +18,7 @@ from onnx2tf.utils.common_functions import (
     make_tf_node_info,
     make_tf_partial_model_inputs,
     dummy_tf_inference,
+    transpose_with_flexing_deterrence,
 )
 from typing import Any, Dict, List
 from onnx2tf.utils.colors import Color
@@ -97,6 +98,60 @@ def make_node(
     }
 
     # Generation of TF OP
+
+    # Workaround to avoid as many conversion failures as possible
+    # for models with useless Transpose immediately before them.
+    # If the input geometry of the ONNX and the input geometry of the TF model match,
+    # the input geometry on the TF model side is forcibly transposed to the NWC or NHWC or NDHWC format.
+    # However, if all dimensions of CW or CHW or CDHW have the same value,
+    # the forced transposition process is skipped because it may destroy the structure of the model.
+    onnx_input_shape = [
+        dim if isinstance(dim, int) else None for dim in graph_node.inputs[0].shape
+    ]
+    tf_input_shape = [
+        dim if isinstance(dim, int) else None for dim in input_tensor_shape
+    ]
+    tf_transposed_perm = None
+    test_data_transposed_perm = None
+    if len(onnx_input_shape) > 1 and len(tf_input_shape) > 1 \
+        and onnx_input_shape == tf_input_shape:
+
+        shape_for_judging_skip = [
+            dim if dim is not None else INF_INDEX_VALUE for dim in onnx_input_shape[1:]
+        ]
+        if shape_for_judging_skip.count(shape_for_judging_skip[0]) != len(shape_for_judging_skip):
+            if len(onnx_input_shape) == 3:
+                # 1D - Overall model
+                input_tensor = transpose_with_flexing_deterrence(
+                    input_tensor=input_tensor,
+                    perm=[0,2,1],
+                    **kwargs,
+                )
+                tf_transposed_perm = [0,2,1]
+            elif len(onnx_input_shape) == 4:
+                # 2D - Overall model
+                input_tensor = transpose_with_flexing_deterrence(
+                    input_tensor=input_tensor,
+                    perm=[0,2,3,1],
+                    **kwargs,
+                )
+                tf_transposed_perm = [0,2,3,1]
+            elif len(onnx_input_shape) == 5:
+                # 3D - Overall model
+                input_tensor = transpose_with_flexing_deterrence(
+                    input_tensor=input_tensor,
+                    perm=[0,2,3,4,1],
+                    **kwargs,
+                )
+                tf_transposed_perm = [0,2,3,4,1]
+    else:
+        if len(onnx_input_shape) == 3:
+            test_data_transposed_perm = [0,2,1]
+        elif len(onnx_input_shape) == 4:
+            test_data_transposed_perm = [0,2,3,1]
+        elif len(onnx_input_shape) == 5:
+            test_data_transposed_perm = [0,2,3,4,1]
+
     """
     Conv1D
     Conv2D
@@ -141,7 +196,6 @@ def make_node(
         print(error_msg)
         assert False, error_msg
 
-
     # DepthwiseConv2D
     #   1. rank=4
     #   2. group>1
@@ -161,56 +215,6 @@ def make_node(
         depthwise_filter_shape = list(input_weights_shape[0:2]) + [-1, input_weights_shape[3] // group]
         input_weights = tf.reshape(input_weights, depthwise_filter_shape)
 
-    # Workaround to avoid as many conversion failures as possible
-    # for models with useless Transpose immediately before them.
-    # If the input geometry of the ONNX and the input geometry of the TF model match,
-    # the input geometry on the TF model side is forcibly transposed to the NWC or NHWC or NDHWC format.
-    # However, if all dimensions of CW or CHW or CDHW have the same value,
-    # the forced transposition process is skipped because it may destroy the structure of the model.
-    onnx_input_shape = [
-        dim if isinstance(dim, int) else None for dim in graph_node.inputs[0].shape
-    ]
-    tf_input_shape = [
-        dim if isinstance(dim, int) else None for dim in input_tensor_shape
-    ]
-    tf_transposed_perm = None
-    test_data_transposed_perm = None
-    if len(onnx_input_shape) > 1 and len(tf_input_shape) > 1 \
-        and onnx_input_shape == tf_input_shape:
-
-        shape_for_judging_skip = [
-            dim if dim is not None else INF_INDEX_VALUE for dim in onnx_input_shape[1:]
-        ]
-        if shape_for_judging_skip.count(shape_for_judging_skip[0]) != len(shape_for_judging_skip):
-            if len(onnx_input_shape) == 3:
-                # 1D - Overall model
-                input_tensor = tf.transpose(
-                    a=input_tensor,
-                    perm=[0,2,1],
-                )
-                tf_transposed_perm = [0,2,1]
-            elif len(onnx_input_shape) == 4:
-                # 2D - Overall model
-                input_tensor = tf.transpose(
-                    a=input_tensor,
-                    perm=[0,2,3,1],
-                )
-                tf_transposed_perm = [0,2,3,1]
-            elif len(onnx_input_shape) == 5:
-                # 3D - Overall model
-                input_tensor = tf.transpose(
-                    a=input_tensor,
-                    perm=[0,2,3,4,1],
-                )
-                tf_transposed_perm = [0,2,3,4,1]
-    else:
-        if len(onnx_input_shape) == 3:
-            test_data_transposed_perm = [0,2,1]
-        elif len(onnx_input_shape) == 4:
-            test_data_transposed_perm = [0,2,3,1]
-        elif len(onnx_input_shape) == 5:
-            test_data_transposed_perm = [0,2,3,4,1]
-
     # Generate input OPs for TensorFlow subgraphs
     # For inference testing on OP stand-alone
     tf_partial_model_inputs: List[tf.keras.Input] = \
@@ -236,6 +240,7 @@ def make_node(
         test_data = None
         if not isinstance(input_tensor, np.ndarray):
             if not isinstance(graph_node_input, np.ndarray) \
+                and graph_node_input.name in tf_layers_dict \
                 and 'verification_data' in tf_layers_dict[graph_node_input.name].keys():
                 test_data: np.ndarray = tf_layers_dict[graph_node_input.name]['verification_data']
             elif isinstance(graph_node_input, np.ndarray):
