@@ -15,9 +15,13 @@ from onnx2tf.utils.common_functions import (
     post_process_transpose,
     make_tf_partial_model_inputs,
     dummy_tf_inference,
+    transpose_with_flexing_deterrence,
 )
 from typing import Any, Dict, List
-from onnx2tf.utils.enums import NUMPY_DTYPES_TO_TF_DTYPES
+from onnx2tf.utils.enums import (
+    NUMPY_DTYPES_TO_TF_DTYPES,
+    TF_DTYPES_TO_NUMPY_DTYPES,
+)
 
 
 @print_node_info
@@ -103,8 +107,12 @@ def make_node(
         ### Overall model
         tf_layers_dict[graph_node_output.name]['tf_node'] = \
             tf.matmul(
-                a=input_tensor_1,
-                b=input_tensor_2,
+                a=input_tensor_1 \
+                    if not isinstance(input_tensor_1, np.ndarray) \
+                        else tf.convert_to_tensor(input_tensor_1),
+                b=input_tensor_2 \
+                    if not isinstance(input_tensor_2, np.ndarray) \
+                        else tf.convert_to_tensor(input_tensor_2),
                 output_type=output_dtype,
                 name=graph_node.name,
             )
@@ -123,11 +131,30 @@ def make_node(
                 outputs=tf_partial_model_outputs,
             )
             test_data1 = None
-            if isinstance(input_tensor_1, np.ndarray):
+            if not isinstance(input_tensor_1, np.ndarray):
+                if not isinstance(graph_node_input_1, np.ndarray) \
+                    and graph_node_input_1.name in tf_layers_dict \
+                    and 'verification_data' in tf_layers_dict[graph_node_input_1.name].keys():
+                    test_data1: np.ndarray = tf_layers_dict[graph_node_input_1.name]['verification_data']
+                elif isinstance(graph_node_input_1, np.ndarray):
+                    test_data1: np.ndarray = graph_node_input_1
+                else:
+                    test_data1 = None
+            else:
                 test_data1 = input_tensor_1
             test_data2 = None
-            if isinstance(input_tensor_2, np.ndarray):
+            if not isinstance(input_tensor_2, np.ndarray):
+                if not isinstance(graph_node_input_2, np.ndarray) \
+                    and graph_node_input_2.name in tf_layers_dict \
+                    and 'verification_data' in tf_layers_dict[graph_node_input_2.name].keys():
+                    test_data2: np.ndarray = tf_layers_dict[graph_node_input_2.name]['verification_data']
+                elif isinstance(graph_node_input_2, np.ndarray):
+                    test_data2: np.ndarray = graph_node_input_2
+                else:
+                    test_data2 = None
+            else:
                 test_data2 = input_tensor_2
+
             tf_partial_model_result_infos: Dict[Any] = dummy_tf_inference(
                 model=tf_partial_model,
                 inputs=tf_partial_model_inputs,
@@ -157,16 +184,38 @@ def make_node(
                     tf_partial_model_inputs: List[tf.keras.Input] = \
                             make_tf_partial_model_inputs(
                                 input_tensors=[
-                                    np.asarray(input_tensor_1.shape)[tensor_1_candidate_for_transposition],
-                                    np.asarray(input_tensor_2.shape)[tensor_2_candidate_for_transposition],
+                                    np.zeros(
+                                        list(input_tensor_1.shape),
+                                        dtype=input_tensor_1.dtype \
+                                            if isinstance(input_tensor_1, np.ndarray) \
+                                                else TF_DTYPES_TO_NUMPY_DTYPES[input_tensor_1.dtype],
+                                    ).transpose(tensor_1_candidate_for_transposition),
+                                    np.zeros(
+                                        list(input_tensor_2.shape),
+                                        dtype=input_tensor_2.dtype \
+                                            if isinstance(input_tensor_2, np.ndarray) \
+                                                else TF_DTYPES_TO_NUMPY_DTYPES[input_tensor_2.dtype],
+                                    ).transpose(tensor_2_candidate_for_transposition),
                                 ]
                             )
                     tf_partial_model_outputs = None
                     ### Overall model
                     tf_layers_dict[graph_node_output.name]['tf_node'] = \
                         tf.matmul(
-                            a=tf.transpose(a=input_tensor_1, perm=tensor_1_candidate_for_transposition),
-                            b=tf.transpose(a=input_tensor_2, perm=tensor_2_candidate_for_transposition),
+                            a=transpose_with_flexing_deterrence(
+                                input_tensor=input_tensor_1 \
+                                    if not isinstance(input_tensor_1, np.ndarray) \
+                                        else tf.convert_to_tensor(input_tensor_1),
+                                perm=list(tensor_1_candidate_for_transposition),
+                                **kwargs,
+                            ),
+                            b=transpose_with_flexing_deterrence(
+                                input_tensor=input_tensor_2 \
+                                    if not isinstance(input_tensor_2, np.ndarray) \
+                                        else tf.convert_to_tensor(input_tensor_2),
+                                perm=list(tensor_2_candidate_for_transposition),
+                                **kwargs,
+                            ),
                             output_type=output_dtype,
                             name=graph_node.name,
                         )
@@ -175,8 +224,12 @@ def make_node(
                         tf_partial_model_outputs = \
                             [
                                 tf.matmul(
-                                    a=tf.transpose(tf_partial_model_inputs[0], perm=tensor_1_candidate_for_transposition),
-                                    b=tf.transpose(tf_partial_model_inputs[1], perm=tensor_2_candidate_for_transposition),
+                                    a=tf_partial_model_inputs[0] \
+                                        if not isinstance(tf_partial_model_inputs[0], np.ndarray) \
+                                            else tf.convert_to_tensor(tf_partial_model_inputs[0]),
+                                    b=tf_partial_model_inputs[1] \
+                                        if not isinstance(tf_partial_model_inputs[1], np.ndarray) \
+                                            else tf.convert_to_tensor(tf_partial_model_inputs[1]),
                                     output_type=output_dtype,
                                 )
                             ]
@@ -185,11 +238,53 @@ def make_node(
                             outputs=tf_partial_model_outputs,
                         )
                         test_data1 = None
-                        if isinstance(input_tensor_1, np.ndarray):
-                            test_data1 = input_tensor_1
+                        if not isinstance(input_tensor_1, np.ndarray):
+                            if not isinstance(graph_node_input_1, np.ndarray) \
+                                and graph_node_input_1.name in tf_layers_dict \
+                                and 'verification_data' in tf_layers_dict[graph_node_input_1.name].keys():
+                                test_data1: np.ndarray = transpose_with_flexing_deterrence(
+                                    input_tensor=tf_layers_dict[graph_node_input_1.name]['verification_data'],
+                                    perm=list(tensor_1_candidate_for_transposition),
+                                    **kwargs,
+                                )
+                            elif isinstance(graph_node_input_1, np.ndarray):
+                                test_data1: np.ndarray = transpose_with_flexing_deterrence(
+                                    input_tensor=graph_node_input_1,
+                                    perm=list(tensor_1_candidate_for_transposition),
+                                    **kwargs,
+                                )
+                            else:
+                                test_data1 = None
+                        else:
+                            test_data1 = transpose_with_flexing_deterrence(
+                                input_tensor=input_tensor_1,
+                                perm=list(tensor_1_candidate_for_transposition),
+                                **kwargs,
+                            )
                         test_data2 = None
-                        if isinstance(input_tensor_2, np.ndarray):
-                            test_data2 = input_tensor_2
+                        if not isinstance(input_tensor_2, np.ndarray):
+                            if not isinstance(graph_node_input_2, np.ndarray) \
+                                and graph_node_input_2.name in tf_layers_dict \
+                                and 'verification_data' in tf_layers_dict[graph_node_input_2.name].keys():
+                                test_data2: np.ndarray = transpose_with_flexing_deterrence(
+                                    input_tensor=tf_layers_dict[graph_node_input_2.name]['verification_data'],
+                                    perm=list(tensor_2_candidate_for_transposition),
+                                    **kwargs,
+                                )
+                            elif isinstance(graph_node_input_2, np.ndarray):
+                                test_data2: np.ndarray = transpose_with_flexing_deterrence(
+                                    input_tensor=graph_node_input_2,
+                                    perm=list(tensor_2_candidate_for_transposition),
+                                    **kwargs,
+                                )
+                            else:
+                                test_data2 = None
+                        else:
+                            test_data2 = transpose_with_flexing_deterrence(
+                                input_tensor=input_tensor_2,
+                                perm=list(tensor_2_candidate_for_transposition),
+                                **kwargs,
+                            )
                         tf_partial_model_result_infos: Dict[Any] = dummy_tf_inference(
                             model=tf_partial_model,
                             inputs=tf_partial_model_inputs,
