@@ -68,7 +68,7 @@ def make_node(
 
     axes = graph_node.attrs.get('axes', axes)
     noop_with_empty_axes = bool(graph_node.attrs.get('noop_with_empty_axes', 0))
-    if noop_with_empty_axes:
+    if noop_with_empty_axes and axes is None:
         error_msg = f'' +\
             f'{Color.RED}ERROR:{Color.RESET} ' +\
             f'TensorFlow does not support noop_with_empty_axes=1 (True).'
@@ -161,6 +161,7 @@ def make_node(
         test_data = None
         if not isinstance(input_tensor, np.ndarray):
             if not isinstance(graph_node_input_1, np.ndarray) \
+                and graph_node_input_1.name in tf_layers_dict \
                 and 'verification_data' in tf_layers_dict[graph_node_input_1.name].keys():
                 test_data: np.ndarray = tf_layers_dict[graph_node_input_1.name]['verification_data']
             elif isinstance(graph_node_input_1, np.ndarray):
